# Release history

### 0.0.11
* Add documentation about global prefix in readme.

### 0.0.10
* Create a global prefix for unique resources.

### 0.0.9
* Create github pipelines.
* Update code.

### 0.0.8
* Make sure CDK deploy works both on linux based systems and windows based systems.

### 0.0.7
* Bug fix related to environment.

### 0.0.6
* Update pytest dependency version.

### 0.0.5
* Rethink how this framework should be used.

### 0.0.4
* Fix imports.
* Update examples.

### 0.0.3
* Rename project.
* Update gitignore and ignore idea files.
* Update MANIFEST.
* Move examples to a documentation folder.

### 0.0.2
* Add hyperlinks for examples.

### 0.0.1
* Initial build.